@@ -1,9 +1,26 @@
 package Finance::Dogecoin::Utils;
 # ABSTRACT: Libraries and Utilities to work with Dogecoin
-$Finance::Dogecoin::Utils::VERSION = '1.20221211.2353';
+$Finance::Dogecoin::Utils::VERSION = '1.20230424.0253';
 use strict;
 use warnings;
 
+use File::HomeDir;
+use Path::Tiny;
+
+use Exporter::Shiny our @EXPORT = qw( get_conf_dir get_auth_file get_dogecoin_conf_dir );
+
+sub get_conf_dir {
+    return path(File::HomeDir->my_data)->child('dogeutils')->mkdir;
+}
+
+sub get_auth_file {
+    return get_conf_dir()->child( 'auth.json' );
+}
+
+sub get_dogecoin_conf_dir {
+    return path(File::HomeDir->my_home)->child('.dogecoin')->child('backups');
+}
+
 1;
 
 __END__
@@ -18,7 +35,7 @@ Finance::Dogecoin::Utils - Libraries and Utilities to work with Dogecoin
 
 =head1 VERSION
 
-version 1.20221211.2353
+version 1.20230424.0253
 
 =head1 SYNOPSIS
 
@@ -26,7 +43,7 @@ See L<dogeutils>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2022 chromatic
+Copyright (c) 2022-2023 chromatic
 
 =head1 AUTHOR
 
